@@ -109,35 +109,19 @@ sort_ints (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointer
 static GtkWidget *
 create_proctree(GtkTreeModel *model)
 {
-	GtkWidget *proctree = NULL;
-	GModule *sexy;
+	GtkWidget *proctree;
+	GtkWidget* (*new)(void);
+	void (*set_column)(void*, guint);
 
-	sexy = g_module_open("libsexy.so",
-			     G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL);
 
-	if (sexy) {
-		GtkWidget* (*new)(void);
-		void (*set_column)(void*, guint);
-
-		if (g_module_symbol(sexy,
-				    "sexy_tree_view_new",
-				    &new) &&
-		    g_module_symbol(sexy,
-				    "sexy_tree_view_set_tooltip_label_column",
-				    &set_column)) {
-
-			g_module_make_resident(sexy);
-			g_print("Found libsexy\n");
-
-			proctree = new();
-			gtk_tree_view_set_model(GTK_TREE_VIEW(proctree), model);
-			set_column(proctree, COL_ARGS);
-		} else {
-			g_module_close(sexy);
-		}
-	}
-
-	if (!proctree) {
+	if (load_symbols("libsexy.so",
+			 "sexy_tree_view_new", &new,
+			 "sexy_tree_view_set_tooltip_label_column", &set_column,
+			 NULL)) {
+		proctree = new();
+		gtk_tree_view_set_model(GTK_TREE_VIEW(proctree), model);
+		set_column(proctree, COL_TOOLTIP);
+	} else {
 		proctree = gtk_tree_view_new_with_model(model);
 	}
 
@@ -259,19 +243,20 @@ search_equal_func(GtkTreeModel *model,
 {
 	char* name;
 	char* user;
+	gboolean found;
 
 	gtk_tree_model_get(model, iter,
 			   COL_NAME, &name,
 			   COL_USER, &user,
 			   -1);
 
-	if(name && strstr(name, key))
-		return FALSE;
+	found = !((name && strstr(name, key))
+		  || (user && strstr(user, key)));
 
-	if(user && strstr(user, key))
-		return FALSE;
+	g_free(name);
+	g_free(user);
 
-	return TRUE;
+	return found;
 }
 
 
@@ -334,7 +319,8 @@ proctable_new (ProcData * const procdata)
 				    G_TYPE_STRING,	/* Arguments	*/
 				    G_TYPE_STRING,	/* Memory       */
 				    GDK_TYPE_PIXBUF,	/* Icon		*/
-				    G_TYPE_POINTER	/* ProcInfo	*/
+				    G_TYPE_POINTER,	/* ProcInfo	*/
+				    G_TYPE_STRING	/* Sexy tooltip */
 		);
 
 	proctree = create_proctree(GTK_TREE_MODEL(model));
@@ -472,6 +458,7 @@ proctable_free_info(ProcInfo *info)
 	}
 
 	g_free (info->name);
+	g_free(info->tooltip);
 	g_free (info->arguments);
 	g_free (info->security_context);
 	g_slist_free (info->children);
@@ -744,6 +731,7 @@ insert_info_to_tree (ProcInfo *info, ProcData *procdata)
 			    COL_PIXBUF, info->pixbuf,
 			    COL_NAME, info->name,
 			    COL_ARGS, info->arguments,
+			    COL_TOOLTIP, info->tooltip,
 			    COL_PID, info->pid,
 			    COL_SECURITYCONTEXT, info->security_context,
 			    -1);
@@ -902,7 +890,8 @@ procinfo_new (ProcData *procdata, gint pid)
 	get_process_name (info, procstate.cmd, arguments[0]);
 	get_process_user (procdata, info, procstate.uid);
 
-	info->arguments = g_strjoinv(" ", arguments);
+	info->tooltip = g_strjoinv(" ", arguments);
+	info->arguments = g_strescape(info->tooltip, "\\\"");
 	g_strfreev(arguments);
 
 	info->pcpu = 0;
